<?php
/**
 * Do not allow direct access
 *
 * @since    1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) die( 'Don\'t try to load this file directly!' );

if ( ! class_exists( 'ET_Builder_Module' ) ) return;

/**
 * Divi - Filterable Blog Module - Controller Modules Blog Light
 *
 * @since    1.0.0
 */
if ( ! class_exists( 'dfbmModulesLightBlog' ) )
{

    class dfbmModulesLightBlog extends ET_Builder_Module
    {

        /**
         * Define Props
         *
         * @since 1.0.0
         */
        private $cpts;

        /**
         * Initialize the module
         *
         * @since 1.0.0
         */
        public function init()
        {

            /**
             * Set properties
             *
             * @since 1.0.0
             */
            // $this->vb_support = 'on';

            $this->name = esc_html__( DFBM()->light(), DFBM()->domain() );

            $this->slug = 'et_pb_dfbm_blog_light';

            $this->main_css_element = '%%order_class%%';

            $this->cpts = dfbmControllerBlogposts::getPosttypes();

            $this->tax  = dfbmControllerBlogposts::taxFields( $this->cpts );

            $this->fields_defaults = dfbmControllerBlogposts::fieldDefaults();

            $this->settings_modal_toggles = array(
                'general'  => array(
                    'toggles' => array(
                        'layout'           => esc_html__( 'Layout', DFBM()->domain() ),
                        'background'       => esc_html__( 'Background', DFBM()->domain() ),
                        'featured_posts'   => esc_html__( 'Featured Posts', DFBM()->domain() ),
                        'category_nav'     => esc_html__( 'Category Navigation', DFBM()->domain() ),
                        'post_options'     => esc_html__( 'Post Options', DFBM()->domain() ),
                        'content_elements' => esc_html__( 'Content Elements', DFBM()->domain() ),
                        'pagination'       => esc_html__( 'Pagination / Add-More-Button', DFBM()->domain() ),
                        'overlay'          => esc_html__( 'Overlay Settings', DFBM()->domain() ),
                        'lightbox'         => esc_html__( 'Lightbox Settings', DFBM()->domain() ),
                        'script'           => esc_html__( 'Script Settings', DFBM()->domain() ),
                        'scroll'           => esc_html__( 'Scroll Animation', DFBM()->domain() ),
                    ),
                ),
                'advanced' => array(
                    'toggles' => array(
                        'shadow'       => esc_html__( 'Shadow Settings', DFBM()->domain() ),
                        'image' => array(
                            'title' => esc_html__( 'Image', DFBM()->domain() ),
                            'priority' => 51,
                        ),
                        'text'         => array(
                            'title'    => esc_html__( 'Text', DFBM()->domain() ),
                            'priority' => 49,
                        ),
                    ),
                ),
            );

            $this->advanced_fields = array(
                'background' => array(
                    'css' => array(
                        'main' => "{$this->main_css_element}",
                    ),
                    'settings'  => array(
                        'color' => 'alpha',
                    ),
                ),
                'border' => array(
                    'settings' => array(
                        'color' => 'alpha',
                    ),
                    'css'      => array(
                        'main' => "{$this->main_css_element}",
                        'important' => 'plugin_only',
                    ),
                ),
                'custom_margin_padding' => array(
                    'css' => array(
                        'main' => "{$this->main_css_element}",
                        'important' => 'all',
                    ),
                ),
                'max_width' => array(),
                'filters' => array(
                    'child_filters_target' => array(
                        'tab_slug' => 'advanced',
                        'toggle_slug' => 'image',
                    ),
                ),
                'image' => array(
                    'css' => array(
                        'main' => array(
                            '%%order_class%% .et_pb_slides',
                            '%%order_class%% .et_pb_video_overlay',
                            '%%order_class%% .et_pb_image_container',
                        ),
                    ),
                ),
                'text'      => array(
                    'css' => array(
                        'text_shadow' => '%%order_class%%',
                    ),
                ),
            );

            $this->custom_css_fields = [

                'feat_blogs_container' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Container', DFBM()->domain() ),
                    'selector' => '.et_pb_featured_posts',

                ],
                'feat_blogs_inner_article' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Inner Article (Box Shadow)', DFBM()->domain() ),
                    'selector' => '.et_pb_featured_posts .article-inner',

                ],
                'feat_blogs_content_container' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Overlay Content Container', DFBM()->domain() ),
                    'selector' => '
                        .et_pb_featured_posts .et_pb_content_container,
                        .et_pb_featured_posts .content-overlay .et_pb_content_container',

                ],
                'feat_blogs_content_container_hover' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Overlay Content Container:Hover', DFBM()->domain() ),
                    'selector' => '
                        .et_pb_featured_posts article:hover .et_pb_content_container,
                        .et_pb_featured_posts .content-overlay article:hover .et_pb_content_container',

                ],
                'feat_blogs_title' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Header', DFBM()->domain() ),
                    'selector' => '.et_pb_featured_posts .et_pb_post .entry-title',

                ],
                'feat_blogs_content_header_before' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Overlay Header Click Icon', DFBM()->domain() ),
                    'selector' => '
                        .et_pb_featured_posts .et_pb_content_container.click::before,
                        .et_pb_featured_posts .et_pb_content_container.clicked::before',

                ],
                'feat_blogs_post_meta' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Meta', DFBM()->domain() ),
                    'selector' => '.et_pb_featured_posts .et_pb_post .post-meta',

                ],
                'feat_blogs_post_meta_a' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Meta Link', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_bg_layout_light .et_pb_featured_posts .et_pb_post .post-meta a,
                        {$this->main_css_element} .et_pb_bg_layout_dark .et_pb_featured_posts .et_pb_post .post-meta a",

                ],
                'feat_blogs_post_content' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Post Content', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_bg_layout_light .et_pb_featured_posts .post-content,
                        {$this->main_css_element} .et_pb_bg_layout_dark .et_pb_featured_posts .post-content",

                ],
                'feat_blogs_post_body' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Post Body', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_bg_layout_light,
                        {$this->main_css_element} .et_pb_bg_layout_dark,
                        {$this->main_css_element} .et_pb_bg_layout_light .et_pb_featured_posts .post-content *,
                        {$this->main_css_element} .et_pb_bg_layout_dark .et_pb_featured_posts .post-content *",

                ],
                'feat_featured_image' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Featured Image / Gallery', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_featured_posts .et_pb_image_container,
                        {$this->main_css_element} .et_pb_featured_posts .et_pb_slider",

                ],
                'filter_container' =>
                [

                    'label'    => esc_html__( 'Category Filter - Container', DFBM()->domain() ),
                    'selector' => '.et_pb_blog_filters.clearfix',

                ],
                'filter_active_display' =>
                [

                    'label'    => esc_html__( 'Category Filter - Active Category Display', DFBM()->domain() ),
                    'selector' => '.et_pb_blog_filters .dfbm-active-cat',

                ],
                'filter_link_nav' =>
                [

                    'label'    => esc_html__( 'Category Filter - Link Navigation Bar', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_blog_filters.nav a,
                        {$this->main_css_element} .et_pb_blog_filters.text a .dfbm-sub-menu.first a",

                ],
                'filter_link_nav_active' =>
                [

                    'label'    => esc_html__( 'Category Filter - Link Navigation Bar Active & Hover', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_blog_filters.nav a.active,
                        {$this->main_css_element} .et_pb_blog_filters.nav a:hover,
                        {$this->main_css_element} .et_pb_blog_filters.text a .dfbm-sub-menu.first a:hover",

                ],
                'filter_link_text' =>
                [

                    'label'    => esc_html__( 'Category Filter - Link Text Bar', DFBM()->domain() ),
                    'selector' => '.et_pb_blog_filters.text a',

                ],
                'filter_link_text_active' =>
                [

                    'label'    => esc_html__( 'Category Filter - Link Text Bar Active & Hover', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_blog_filters.text a.active,
                        {$this->main_css_element} .et_pb_blog_filters.text a:hover",

                ],
                'filter_link_text_separator' =>
                [

                    'label'    => esc_html__( 'Category Filter - Link Text Bar Separator', DFBM()->domain() ),
                    'selector' => '.et_pb_blog_filter.seperator',

                ],
                'filt_blogs_container' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Container', DFBM()->domain() ),
                    'selector' => '.filterable-blogposts',

                ],
                'filt_blogs_inner_article' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Inner Article (Box Shadow)', DFBM()->domain() ),
                    'selector' => '.filterable-blogposts .article-inner',

                ],
                'filt_blogs_content_container' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Overlay Content Container', DFBM()->domain() ),
                    'selector' => '
                        .filterable-blogposts .et_pb_content_container,
                        .filterable-blogposts .content-overlay .et_pb_content_container',

                ],
                'filt_blogs_content_container_hover' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Overlay Content Container:Hover', DFBM()->domain() ),
                    'selector' => '
                        .filterable-blogposts article:hover .et_pb_content_container,
                        .filterable-blogposts .content-overlay article:hover .et_pb_content_container',

                ],
                'filt_blogs_title' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Header', DFBM()->domain() ),
                    'selector' => '.filterable-blogposts .et_pb_post .entry-title',

                ],
                'filt_blogs_content_header_before' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Overlay Header Click Icon', DFBM()->domain() ),
                    'selector' => '
                        .filterable-blogposts .et_pb_content_container.click::before,
                        .filterable-blogposts .et_pb_content_container.clicked::before',

                ],
                'filt_blogs_post_meta' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Meta', DFBM()->domain() ),
                    'selector' => '.filterable-blogposts .et_pb_post .post-meta',

                ],
                'filt_blogs_post_meta_a' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Meta Link', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_bg_layout_light .filterable-blogposts .et_pb_post .post-meta a,
                        {$this->main_css_element} .et_pb_bg_layout_dark .filterable-blogposts .et_pb_post .post-meta a",

                ],
                'feat_blogs_post_content' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Post Content', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_bg_layout_light .filterable-blogposts .post-content,
                        {$this->main_css_element} .et_pb_bg_layout_dark .filterable-blogposts .post-content",

                ],
                'feat_blogs_post_body' =>
                [

                    'label'    => esc_html__( 'Featured Posts - Post Body', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .et_pb_bg_layout_light .filterable-blogposts,
                        {$this->main_css_element} .et_pb_bg_layout_dark .filterable-blogposts,
                        {$this->main_css_element} .et_pb_bg_layout_light ..filterable-blogposts .post-content *,
                        {$this->main_css_element} .et_pb_bg_layout_dark ..filterable-blogposts .post-content *",

                ],
                'filt_featured_image' =>
                [

                    'label'    => esc_html__( 'Filterable Posts - Featured Image / Gallery', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .filterable-blogposts .et_pb_image_container,
                        {$this->main_css_element} .filterable-blogposts .et_pb_slider",

                ],
                'read_more' =>
                [

                    'label'    => esc_html__( 'Read More Button', DFBM()->domain() ),
                    'selector' => "body.et_pb_button_helper_class {$this->main_css_element} .et_pb_button.read-more",

                ],
                'read_more_after' =>
                [

                    'label'    => esc_html__( 'Read More Button::After', DFBM()->domain() ),
                    'selector' => "body.et_pb_button_helper_class {$this->main_css_element} .et_pb_button.read-more::after",

                ],
                'read_more_hover' =>
                [

                    'label'    => esc_html__( 'Read More Button:Hover', DFBM()->domain() ),
                    'selector' => "body.et_pb_button_helper_class {$this->main_css_element} .et_pb_button.read-more:hover",

                ],
                'read_more_hover_after' =>
                [

                    'label'    => esc_html__( 'Read More Button:Hover::After', DFBM()->domain() ),
                    'selector' => "body.et_pb_button_helper_class {$this->main_css_element} .et_pb_button.read-more:hover::after",

                ],
                'add_more_container' =>
                [

                    'label'    => esc_html__( 'Add More Container', DFBM()->domain() ),
                    'selector' => '.add-more-section',

                ],
                'add_more' =>
                [

                    'label'    => esc_html__( 'Add More Button', DFBM()->domain() ),
                    'selector' => "body.et_pb_button_helper_class {$this->main_css_element} .et_pb_button.add-more-button",

                ],
                'add_more_after' =>
                [

                    'label'    => esc_html__( 'Add More Button::After', DFBM()->domain() ),
                    'selector' => "body.et_pb_button_helper_class {$this->main_css_element} .et_pb_button.add-more-button::after",

                ],
                'add_more_hover' =>
                [

                    'label'    => esc_html__( 'Add More Button:Hover', DFBM()->domain() ),
                    'selector' => "body.et_pb_button_helper_class {$this->main_css_element} .et_pb_button.add-more-button:hover",

                ],
                'add_more_hover_after' =>
                [

                    'label'    => esc_html__( 'Add More Button:Hover::After', DFBM()->domain() ),
                    'selector' => "body.et_pb_button_helper_class {$this->main_css_element} .et_pb_button.add-more-button:hover::after",

                ],
                'pagination_container' =>
                [

                    'label'    => esc_html__( 'Pagination Container', DFBM()->domain() ),
                    'selector' => '.dfbm_blog_pagination',

                ],
                'pagination_text' =>
                [

                    'label'    => esc_html__( 'Pagination Text', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .dfbm_blog_pagination a,
                        {$this->main_css_element} .dfbm_blog_pagination span",

                ],
                'pagination_text_current' =>
                [

                    'label'    => esc_html__( 'Pagination Text Current', DFBM()->domain() ),
                    'selector' => "{$this->main_css_element} .dfbm_blog_pagination .current",

                ],
                'lightbox_header' =>
                [

                    'label'    => esc_html__( 'Lightbox Header', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .lb-pseudo,
                        .dfbm-lb-header",

                ],
                'lightbox_close' =>
                [

                    'label'    => esc_html__( 'Lightbox Close Link', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .lb-pseudo,
                        .dfbm-lb-close,
                        .dfbm-lb-close::after",

                ],
                'lightbox_close_hover' =>
                [

                    'label'    => esc_html__( 'Lightbox Close Link:Hover', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .lb-pseudo,
                        .dfbm-lb-close:hover,
                        .dfbm-lb-close:hover::after",

                ],
                'lightbox_title' =>
                [

                    'label'    => esc_html__( 'Lightbox Title', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .lb-pseudo,
                        .dfbm-lb-link .dfbm-lb-title",

                ],
                'lightbox_title_hover' =>
                [

                    'label'    => esc_html__( 'Lightbox Title:Hover', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .lb-pseudo,
                        .dfbm-lb-link .dfbm-lb-title:hover",

                ],
                'lightbox_read_more' =>
                [

                    'label'    => esc_html__( 'Lightbox Read More', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .lb-pseudo,
                        .dfbm-lb-read-more .dfbm-lb-title",

                ],
                'lightbox_read_more_hover' =>
                [

                    'label'    => esc_html__( 'Lightbox Read More:Hover', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .lb-pseudo,
                        .dfbm-lb-read-more .dfbm-lb-title:hover",

                ],
                'woo_price_text' =>
                [

                    'label'    => esc_html__( 'WooCommerce Price Text', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .price,
                        {$this->main_css_element} .price > .woocommerce-Price-amount,
                        {$this->main_css_element} .price > .woocommerce-Price-amount .woocommerce-Price-currencySymbol,
                        {$this->main_css_element} del,
                        {$this->main_css_element} del .woocommerce-Price-amount,
                        {$this->main_css_element} del .woocommerce-Price-amount .woocommerce-Price-currencySymbol",

                ],
                'woo_onsale_text' =>
                [

                    'label'    => esc_html__( 'WooCommerce Onsale Text', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} ins,
                        {$this->main_css_element} ins .woocommerce-Price-amount,
                        {$this->main_css_element} ins .woocommerce-Price-amount .woocommerce-Price-currencySymbol",

                ],
                'woo_price_text_fb' =>
                [

                    'label'    => esc_html__( 'WooCommerce Price Text - Filterable Blogs', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .filterable-blogposts .price,
                        {$this->main_css_element} .filterable-blogposts .price > .woocommerce-Price-amount,
                        {$this->main_css_element} .filterable-blogposts .price > .woocommerce-Price-amount .woocommerce-Price-currencySymbol,
                        {$this->main_css_element} .filterable-blogposts del,
                        {$this->main_css_element} .filterable-blogposts del .woocommerce-Price-amount,
                        {$this->main_css_element} .filterable-blogposts del .woocommerce-Price-amount .woocommerce-Price-currencySymbol",

                ],
                'woo_onsale_text_fb' =>
                [

                    'label'    => esc_html__( 'WooCommerce Onsale Text - Filterable Blogs', DFBM()->domain() ),
                    'selector' => "
                        {$this->main_css_element} .filterable-blogposts ins,
                        {$this->main_css_element} .filterable-blogposts ins .woocommerce-Price-amount,
                        {$this->main_css_element} .filterable-blogposts ins .woocommerce-Price-amount .woocommerce-Price-currencySymbol",

                ],
            ];

        } // end init

        public function get_fields()
        {

            foreach ( $this->cpts as $cpt ) :

                $cat = dfbmControllerBlogposts::getTaxonomySlug( $cpt, 'cat' );

                $tag = dfbmControllerBlogposts::getTaxonomySlug( $cpt, 'tag' );

                if ( ! $cat || ! $tag )
                    continue;

                $options[ $cpt ] = esc_html__( ucfirst( $cpt ), DFBM()->domain() );

                $second['custom_posttypes'] =
                [

                    'label'             => esc_html__( 'Posttype', DFBM()->domain() ),
                    'type'              => 'select',
                    'option_category'   => 'configuration',
                    'options'             => $options,
                    'affects'           => array_merge(
                                           [

                                                 'show_star_rating',
                                                 'star_rating_color',
                                                 'star_rating_color_bg',
                                                 'star_rating_color_fb',
                                                 'star_rating_color_bg_fb',
                                                 'show_product_price',
                                                 'show_add_to_cart',
                                                 'add_to_cart_color',

                                              'price_text_font',
                                              'price_text_text_color',
                                              'price_text_line_height',
                                              'price_text_font_size',
                                              'price_text_all_caps',
                                              'price_text_letter_spacing',

                                              'onsale_text_font',
                                              'onsale_text_text_color',
                                              'onsale_text_line_height',
                                              'onsale_text_font_size',
                                              'onsale_text_all_caps',
                                              'onsale_text_letter_spacing',

                                              'price_text_fb_font',
                                              'price_text_fb_text_color',
                                              'price_text_fb_line_height',
                                              'price_text_fb_font_size',
                                              'price_text_fb_all_caps',
                                              'price_text_fb_letter_spacing',

                                              'onsale_text_fb_font',
                                              'onsale_text_fb_text_color',
                                              'onsale_text_fb_line_height',
                                              'onsale_text_fb_font_size',
                                              'onsale_text_fb_all_caps',
                                              'onsale_text_fb_letter_spacing',

                                           ], $this->tax ),
                    'description'       => esc_html__( 'Select the posttype that you would like to use', DFBM()->domain() ),
                    'tab_slug'          => 'general',
                    'toggle_slug'       => 'post_options',
                    'computed_affects'  => [ '__posts', ],

                ];

                $second['include_' . $cpt . '_categories'] =
                [

                    'label'            => esc_html__( 'Include ' . ucfirst( $cpt ) . ' Categories', DFBM()->domain() ),
                    'renderer'         => dfbmControllerBlogposts::getCategories( [], $cat, 'include_' . $cpt, $cpt ),
                    'option_category'  => 'basic_option',
                    'description'      => esc_html__( 'Select the categories you would like to include in the feed. If none is selected, all available categories are automatically included.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'post_options',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => $cpt,

                ];

                $second['exclude_' . $cpt . '_categories'] =
                [

                    'label'            => esc_html__( 'Exclude ' . ucfirst( $cpt ) . ' Categories', DFBM()->domain() ),
                    'renderer'         => dfbmControllerBlogposts::getCategories( [], $cat, 'exclude_' . $cpt, $cpt ),
                    'option_category'  => 'basic_option',
                    'description'      => esc_html__( 'Select the categories you don\'t want to include in the feed.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'post_options',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => $cpt,

                ];

                $second['include_' . $cpt . '_tags'] =
                [

                    'label'            => esc_html__( 'Include ' . ucfirst( $cpt ) . ' Tags', DFBM()->domain() ),
                    'renderer'         => dfbmControllerBlogposts::getTags( [], $tag, 'include_' . $cpt, $cpt ),
                    'option_category'  => 'basic_option',
                    'description'      => esc_html__( 'Select the tags you would like to include in the feed. If none is selected, all available tags are automatically included.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'post_options',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => $cpt,

                ];

                $second['exclude_' . $cpt . '_tags'] =
                [

                    'label'            => esc_html__( 'Exclude ' . ucfirst( $cpt ) . ' Tags', DFBM()->domain() ),
                    'renderer'         => dfbmControllerBlogposts::getTags( [], $tag, 'exclude_' . $cpt, $cpt ),
                    'option_category'  => 'basic_option',
                    'description'      => esc_html__( 'Select the tags you don\'t want to include in the feed.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'post_options',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => $cpt,

                ];

            endforeach;

            $first =
            [

                'dfbm_fullwidth' => array(
                    'label'           => esc_html__( 'Layout', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'layout',
                    'options'         => array(
                        'on'  => esc_html__( 'Fullwidth', DFBM()->domain() ),
                        'off' => esc_html__( 'Masonry', DFBM()->domain() ),
                    ),
                    'affects' => array(
                        'column_max',
                        'content_below_image',
                        'thumb_same_height',
                    ),
                    'description'      => esc_html__( 'Toggle between the various blog layout types.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'layout',
                    'computed_affects'  => [ '__posts', ],
                ),
                'content_below_image' => array(
                    'label'           => esc_html__( 'Content below the Image', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description'      => esc_html__( 'This will show the content below the featured image.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'layout',
                    'depends_show_if'  => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'article_distance' => array(
                    'label'           => esc_html__( 'Article Distance', DFBM()->domain() ),
                    'type'            => 'range',
                    'option_category' => 'layout',
                    'default'         => '5',
                    'range_settings'  => array(
                        'min'  => '0',
                        'max'  => '30',
                        'step' => '1',
                    ),
                    'description'      => esc_html__( 'Define the space between the items in pixel for the featured- and the filterable posts.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'layout',
                    'computed_affects'  => [ '__posts', ],
                ),
                'column_max' => array(
                    'label'           => esc_html__( 'Maximum Columns', DFBM()->domain() ),
                    'type'            => 'range',
                    'option_category' => 'layout',
                    'default'         => '3',
                    'range_settings'  => array(
                        'min'  => '1',
                        'max'  => '5',
                        'step' => '1',
                    ),
                    'description'      => esc_html__( 'Define the maximum columns for your masonry-posts.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'layout',
                    'depends_show_if'  => 'off',
                    'computed_affects'  => [ '__posts', ],
                ),
                'item_animation' => array(
                    'label'           => esc_html__( 'Blog Post Animation', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'layout',
                    'options'         => array(
                        'screwed' => esc_html__( 'Screwed-In', DFBM()->domain() ),
                        'faded'   => esc_html__( 'Fade-In', DFBM()->domain() ),
                    ),
                    'description'      => esc_html__( 'Toggle between the various blog post animation types.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'layout',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_posts_featured' => array(
                    'label'           => esc_html__( 'Show Featured Posts', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'This will turn featured posts on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'featured_posts',
                    'affects' => array(
                        'posts_featured',
                        'featured_overlay_color',
                        'layout_before_posts',
                    ),
                    'computed_affects'  => [ '__posts', ],
                ),
                'posts_featured'      => array(
                    'label'           => esc_html__( 'Featured Posts', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description'     => esc_html__( 'Here you can paste the comma separated IDs of your featured posts (3 max). The posts are displayed in the order of the IDs.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'featured_posts',
                    'depends_show_if'  => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'featured_overlay_color' => array(
                    'label'              => esc_html__( 'Featured Posts Overlay Color', DFBM()->domain() ),
                    'type'               => 'color-alpha',
                    'custom_color'       => true,
                    'description'        => esc_html__( 'Here you can define a custom color for the featured posts overlay.', DFBM()->domain() ),
                    'tab_slug'        => 'general',
                    'toggle_slug'     => 'featured_posts',
                    'depends_show_if' => 'on',
                ),
                'layout_before_posts' => array(
                    'label'           => esc_html__( 'Show Layout Before Filterable Posts', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description'     => esc_html__( 'Here you can paste a Layout-ID to display this layout between the fetaured- and the filterable posts.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'featured_posts',
                    'depends_show_if'  => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_category_filter' => array(
                    'label'            => esc_html__( 'Show Category Filter', DFBM()->domain() ),
                    'type'             => 'yes_no_button',
                    'option_category'  => 'configuration',
                    'options' => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'This will turn the category filter on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'category_nav',
                    'affects' => array(
                        'category_filter_style',
                    ),
                    'computed_affects'  => [ '__posts', ],
                ),
                'category_filter_style' => array(
                    'label'           => esc_html__( 'Category Filter Style', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'configuration',
                    'options' => array(
                        'nav'  => esc_html__( 'Navigation Bar', DFBM()->domain() ),
                        'text' => esc_html__( 'Text with Seperators', DFBM()->domain() ),
                    ),
                    'depends_show_if' => 'on',
                    'description'     => esc_html__( 'Choose between a navigation bar and a text style with a seperator.', DFBM()->domain() ),
                    'tab_slug'        => 'general',
                    'toggle_slug'     => 'category_nav',
                    'computed_affects'  => [ '__posts', ],
                ),
            ];

            $third =
            [

                'posts_number' => array(
                    'label'           => esc_html__( 'Posts Number', DFBM()->domain() ),
                    'type'            => 'range',
                    'option_category' => 'layout',
                    'default'         => '6',
                    'range_settings' => array(
                        'min'  => '1',
                        'max'  => '30',
                        'step' => '1',
                    ),
                    'description' => esc_html__( 'Define the number of blogs that should be displayed per page.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'post_options',
                    'tab_slug' => 'general',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_order_options' => array(
                    'label'           => esc_html__( 'Show Order Options', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options' => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'This will turn order options on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'post_options',
                    'affects' => array(
                        'order_options_order',
                        'order_options_orderby',
                    ),
                    'computed_affects'  => [ '__posts', ],
                ),
                'order_options_order' => array(
                    'label'           => esc_html__( 'Order', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'layout',
                    'options' => array(
                        'DESC'  => esc_html__( 'DESC', DFBM()->domain() ),
                        'ASC' => esc_html__( 'ASC', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Toggle between DESC (from highest to lowest) and ASC (from lowest to highest).', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'post_options',
                    'computed_affects'  => [ '__posts', ],
                ),
                'order_options_orderby' => array(
                    'label'             => esc_html__( 'Orderby', DFBM()->domain() ),
                    'type'              => 'select',
                    'option_category'   => 'layout',
                    'options' => array(
                        'date'             => esc_html__( 'Date', DFBM()->domain() ),
                        'title'            => esc_html__( 'Title', DFBM()->domain() ),
                        'author'           => esc_html__( 'Author', DFBM()->domain() ),
                        'comment_count'    => esc_html__( 'Comment Count', DFBM()->domain() ),
                        'menu_order title' => esc_html__( 'Menu Order Title', DFBM()->domain() ),
                        'modified'         => esc_html__( 'Modified', DFBM()->domain() ),
                        'rand'             => esc_html__( 'Random', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Toggle between orderby parameters.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'post_options',
                    'computed_affects'  => [ '__posts', ],
                ),
                'offset_number' => array(
                    'label'           => esc_html__( 'Offset Number', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description' => esc_html__( 'Choose how many posts you would like to offset by.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'post_options',
                    'computed_affects'  => [ '__posts', ],
                ),
                'hide_content' => array(
                    'label'           => esc_html__( 'Hide the Content', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options' => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'This will turn the content below the image on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'post_content_background_color' => array(
                    'label'        => esc_html__( 'Content Background Color', DFBM()->domain() ),
                    'type'         => 'color-alpha',
                    'custom_color' => true,
                    'description' => esc_html__( 'Here you can specify the background color of the content area.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                ),
                'content_absolute' => array(
                    'label'           => esc_html__( 'Show Content as Overlay', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'layout',
                    'options' => array(
                        'off' => esc_html__( 'Off', DFBM()->domain() ),
                        'on'  => esc_html__( 'On', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'If enabled, the content from the filterable posts will be used as overlay (like it is used for the featured posts).', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'content_absolute_event' => array(
                    'label'           => esc_html__( 'Content Overlay Event', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'layout',
                    'options' => array(
                        'on'  => esc_html__( 'Click', DFBM()->domain() ),
                        'off' => esc_html__( 'Hover', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Here you can specify whether the content overlay appears with a click or by hover.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_thumbnail' => array(
                    'label'           => esc_html__( 'Show Featured Image', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'This will turn featured images on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'thumb_same_height' => array(
                    'label'           => esc_html__( 'Same Height for Images', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options' => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'This will adjust the image height to a pre-defined value.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'affects' => array(
                        'define_thumb_height',
                    ),
                    'depends_show_if'  => 'off',
                    'computed_affects'  => [ '__posts', ],
                ),
                'define_thumb_height' => array(
                    'label'            => esc_html__( 'Image Height', DFBM()->domain() ),
                    'type'            => 'range',
                    'option_category' => 'layout',
                    'default'         => '235',
                    'range_settings'  => array(
                        'min'  => '0',
                        'max'  => '500',
                        'step' => '10',
                    ),
                    'description' => esc_html__( 'Define the height for the images in pixel.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_header' => array(
                    'label'           => esc_html__( 'Show Post Header', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Turn post header on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'affects' => array(
                        'header_tag',
                    ),
                    'computed_affects'  => [ '__posts', ],
                ),
                'header_tag' => array(
                    'label'           => esc_html__( 'Post Header Tag', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'h2' => esc_html__( 'h2', DFBM()->domain() ),
                        'h3' => esc_html__( 'h3', DFBM()->domain() ),
                        'h4' => esc_html__( 'h4', DFBM()->domain() ),
                    ),
                    'depends_show_if'  => 'on',
                    'description' => esc_html__( 'Choose the tag to wrap your header.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_content' => array(
                    'label'           => esc_html__( 'Content', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'excerpt' => esc_html__( 'Show Excerpt', DFBM()->domain() ),
                        'content' => esc_html__( 'Show Content', DFBM()->domain() ),
                        'none'    => esc_html__( 'None', DFBM()->domain() ),
                    ),
                    'affects' => array(
                        'show_limit_words',
                    ),
                    'description' => esc_html__( 'Select whether the excerpt, the content, or neither should be displayed.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_limit_words' => array(
                    'label'           => esc_html__( 'Content Limit', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'affects' => array(
                        'limit_words_count',
                    ),
                    'description' => esc_html__( 'Turn word count limit on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'depends_show_if_not' => 'none',
                    'computed_affects'  => [ '__posts', ],
                ),
                'limit_words_count' => array(
                    'label'           => esc_html__( 'Content Word Count', DFBM()->domain() ),
                    'type'            => 'range',
                    'option_category' => 'layout',
                    'default'         => '30',
                    'range_settings'  => array(
                        'min'  => '1',
                        'max'  => '100',
                        'step' => '1',
                    ),
                    'description' => esc_html__( 'Limit the count of words from the content or excerpt.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'depends_show_if' => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_comments' => array(
                    'label'           => esc_html__( 'Show Comment Count', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Turn comment count on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_categories' => array(
                    'label'           => esc_html__( 'Show Categories', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'affects' => array(
                        'show_limit_categories',
                    ),
                    'description' => esc_html__( 'Turn the category links on or off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_limit_categories' => array(
                    'label'             => esc_html__( 'Limit Categories', DFBM()->domain() ),
                    'type'              => 'yes_no_button',
                    'option_category'   => 'configuration',
                    'options'           => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'affects' => array(
                        'limit_category_count',
                    ),
                    'description' => esc_html__( 'Turn category count limit on and off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'depends_show_if'  => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'limit_category_count' => array(
                    'label'            => esc_html__( 'Category Count', DFBM()->domain() ),
                    'type'             => 'range',
                    'option_category'  => 'layout',
                    'default'          => '3',
                    'range_settings' => array(
                        'min'  => '1',
                        'max'  => '10',
                        'step' => '1',
                    ),
                    'description' => esc_html__( 'Limit the count of categories displayed in your posts.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'depends_show_if'  => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_author' => array(
                    'label'           => esc_html__( 'Show Author', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Turn on or off the author link.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_date' => array(
                    'label'           => esc_html__( 'Show Date', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Turn the date on or off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'meta_date' => array(
                    'label'           => esc_html__( 'Meta Date Format', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description' => esc_html__( 'If you would like to adjust the date format, input the appropriate PHP date format here.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_star_rating' => array(
                    'label'           => esc_html__( 'Show Rating Stars', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Turn product rating stars on or off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => 'product',
                ),
                'star_rating_color' => array(
                    'label'           => esc_html__( 'Star Rating Color', DFBM()->domain() ),
                    'type'            => 'color-alpha',
                    'custom_color'    => true,
                    'description'     => esc_html__( 'Here you can define a custom color for the rating stars.', DFBM()->domain() ),
                    'tab_slug'        => 'general',
                    'toggle_slug'     => 'content_elements',
                    'depends_show_if' => 'product',
                ),
                'star_rating_color_bg' => array(
                    'label'            => esc_html__( 'Star Rating Color Background', DFBM()->domain() ),
                    'type'             => 'color-alpha',
                    'custom_color'     => true,
                    'description'      => esc_html__( 'Here you can define a custom color for the rating stars background.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'content_elements',
                    'depends_show_if'  => 'product',
                ),
                'star_rating_color_fb' => array(
                    'label'            => esc_html__( 'Filterable Blogs Star Rating Color', DFBM()->domain() ),
                    'type'             => 'color-alpha',
                    'custom_color'     => true,
                    'description'      => esc_html__( 'Here you can define a custom color for the filterable blogs rating stars.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'content_elements',
                    'depends_show_if'  => 'product',
                ),
                'star_rating_color_bg_fb' => array(
                    'label'           => esc_html__( 'Filterable Blogs Star Rating Color Background', DFBM()->domain() ),
                    'type'            => 'color-alpha',
                    'custom_color'    => true,
                    'description'     => esc_html__( 'Here you can define a custom color for the filterable blogs rating stars background.', DFBM()->domain() ),
                    'tab_slug'        => 'general',
                    'toggle_slug'     => 'content_elements',
                    'depends_show_if' => 'product',
                ),
                'show_product_price' => array(
                    'label'           => esc_html__( 'Show Price', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'description'      => esc_html__( 'Turn the price on or off.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => 'product',
                ),
                'show_add_to_cart' => array(
                    'label'           => esc_html__( 'Show Add to Cart Icon', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'description'      => esc_html__( 'Turn the add to card icon for simple products on or off.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => 'product',
                ),
                'add_to_cart_color' => array(
                    'label'           => esc_html__( 'Add to Cart Icon Color', DFBM()->domain() ),
                    'type'            => 'color-alpha',
                    'custom_color'    => true,
                    'description'     => esc_html__( 'Here you can define a custom color for the add to card icon.', DFBM()->domain() ),
                    'tab_slug'        => 'general',
                    'toggle_slug'     => 'content_elements',
                    'depends_show_if' => 'product',
                ),
                'read_more' => array(
                    'label'           => esc_html__( 'Read More Button', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'On', DFBM()->domain() ),
                        'off' => esc_html__( 'Off', DFBM()->domain() ),
                    ),
                    'affects' => array(
                        'read_more_text',
                    ),
                    'description'      => esc_html__( 'Here you can define whether to show "read more" button or not.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'content_elements',
                    'computed_affects'  => [ '__posts', ],
                ),
                'read_more_text' => array(
                    'label'           => esc_html__( 'Change the text "Read More"', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description'     => esc_html__( 'Here you can change the text "Read More" for the buttons of the individual post items and for the lightbox. Just leave the field blank if you want to use the standard text or change the text using the translation file.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'content_elements',
                    'depends_show_if'  => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'show_pagination' => array(
                    'label'           => esc_html__( 'Show Pagination / Add More', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                    ),
                    'affects' => array(
                        'add_more_button',
                        'pagination_text_font',
                        'pagination_text_text_color',
                        'pagination_text_line_height',
                        'pagination_text_font_size',
                        'pagination_text_all_caps',
                        'pagination_text_letter_spacing',
                        'pagination_text_current_font',
                        'pagination_text_current_text_color',
                        'pagination_text_current_line_height',
                        'pagination_text_current_font_size',
                        'pagination_text_current_all_caps',
                        'pagination_text_current_letter_spacing',
                    ),
                    'description'      => esc_html__( 'Add pagination or an "add more" button.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'pagination',
                    'computed_affects'  => [ '__posts', ],
                ),
                'add_more_button' => array(
                    'label'           => esc_html__( 'Pagination or Add more', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'layout',
                    'options'         => array(
                        'off' => esc_html__( 'Show Pagination', DFBM()->domain() ),
                        'on'  => esc_html__( 'Add More Button', DFBM()->domain() ),
                    ),
                    'depends_show_if' => 'on',
                    'affects'         => array(
                        'add_more_text',
                        'add_more_fullwidth',
                    ),
                    'description'      => esc_html__( 'Toggle between pagination and an "add more" button.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'pagination',
                    'computed_affects'  => [ '__posts', ],
                ),
                'add_more_text' => array(
                    'label'           => esc_html__( 'Change the text "Add More Posts"', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description'     => esc_html__( 'Here you can change the text "Add More Posts" for the "add more" button. Just leave the field blank if you want to use the standard text or change the text using the translation file.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'pagination',
                    'depends_show_if'  => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'add_more_fullwidth' => array(
                    'label'           => esc_html__( 'Fullwidth Add More Button', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'depends_show_if' => 'on',
                    'description'      => esc_html__( 'Set "add more" button to fullwidth.', DFBM()->domain() ),
                    'tab_slug'         => 'general',
                    'toggle_slug'      => 'pagination',
                    'computed_affects'  => [ '__posts', ],
                ),
                'use_overlay' => array(
                    'label'           => esc_html__( 'Featured Image Overlay', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'layout',
                    'options'         => array(
                        'off' => esc_html__( 'Off', DFBM()->domain() ),
                        'on'  => esc_html__( 'On', DFBM()->domain() ),
                    ),
                    'affects' => array(
                        'overlay_icon_color',
                        'hover_overlay_color',
                        'hover_icon',
                        'use_overlay_featured',
                    ),
                    'description' => esc_html__( 'If enabled, an overlay and icon will be displayed when a visitors hovers over the featured image of a post.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'overlay',
                    'computed_affects'  => [ '__posts', ],
                ),
                'overlay_icon_color' => array(
                    'label'           => esc_html__( 'Overlay Icon Color', DFBM()->domain() ),
                    'type'            => 'color-alpha',
                    'custom_color'    => true,
                    'depends_show_if' => 'on',
                    'description' => esc_html__( 'Here you can define a custom color for the overlay icon.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'overlay',
                ),
                'hover_overlay_color' => array(
                    'label'           => esc_html__( 'Hover Overlay Color', DFBM()->domain() ),
                    'type'            => 'color-alpha',
                    'custom_color'    => true,
                    'depends_show_if' => 'on',
                    'description' => esc_html__( 'Here you can define a custom color for the overlay.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'overlay',
                ),
                'hover_icon' => array(
                    'label'               => esc_html__( 'Hover Icon Picker', DFBM()->domain() ),
                    'type'                => 'text',
                    'option_category'     => 'configuration',
                    'class'               => array( 'et-pb-font-icon' ),
                    'renderer'            => 'select_icon',
                    'renderer_with_field' => true,
                    'depends_show_if'     => 'on',
                    'description' => esc_html__( 'Here you can define a custom icon for the overlay.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'overlay',
                    'computed_affects'  => [ '__posts', ],
                ),
                'use_overlay_featured' => array(
                    'label'           => esc_html__( 'Overlay Featured Posts', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'layout',
                    'options'         => array(
                        'off' => esc_html__( 'Off', DFBM()->domain() ),
                        'on'  => esc_html__( 'On', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Here you can also activate the overlays for featured posts.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'overlay',
                    'depends_show_if' => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'use_dfbm_lightbox' => array(
                    'label'           => esc_html__( 'Use Lightbox', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Turn the lightbox on or off.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'lightbox',
                    'affects'     => array(
                        'lightbox_background',
                        'lightbox_header',
                        'lightbox_close',
                        'lifghtbox_width',
                        'setup_image_pos',
                    ),
                    'computed_affects'  => [ '__posts', ],
                ),
                'lightbox_background' => array(
                    'label'           => esc_html__( 'Lightbox Background Color', DFBM()->domain() ),
                    'type'            => 'color-alpha',
                    'custom_color'    => true,
                    'description' => esc_html__( 'Here you can define a custom color for the lightbox background.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'lightbox',
                    'depends_show_if' => 'on',
                ),
                'lightbox_header' => array(
                    'label'           => esc_html__( 'Lightbox Header Text', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description' => esc_html__( 'Here you can define the header-text for the lightbox.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'lightbox',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if' => 'on',
                ),
                'lightbox_close' => array(
                    'label'           => esc_html__( 'Lightbox Close Text', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description' => esc_html__( 'Here you can define the text next to the close-icon for the lightbox. Default: Close.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'lightbox',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if' => 'on',
                ),
                'lightbox_width' => array(
                    'label'           => esc_html__( 'Lightbox Content Width', DFBM()->domain() ),
                    'type'            => 'range',
                    'option_category' => 'layout',
                    'default'         => '80',
                    'range_settings'  => array(
                        'min'  => '0',
                        'max'  => '100',
                        'step' => '1',
                    ),
                    'description' => esc_html__( 'Here you can define the width of the lightbox content in percent (max 99%).', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'lightbox',
                    'tab_slug' => 'general',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if' => 'on',
                ),
                'setup_image_pos' => array(
                    'label'           => esc_html__( 'Lightbox Image Position', DFBM()->domain() ),
                    'type'            => 'select',
                    'option_category' => 'layout',
                    'options'         => array(
                        'center' => esc_html__( 'Center', DFBM()->domain() ),
                        'top'    => esc_html__( 'Top', DFBM()->domain() ),
                        'bottom' => esc_html__( 'Bottom', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Here you can choose, how your images are positioned in the lightbox.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'lightbox',
                    'depends_show_if'  => 'on',
                    'computed_affects'  => [ '__posts', ],
                ),
                'cdn_origin' => array(
                    'label'           => esc_html__( 'CDN Origin', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'description' => esc_html__( 'Here you must paste your CDN-Origin, if you use a CDN-Service for embedded videos and images ( eg. cdn.my-domain.com ). Without the protocoll and slashes.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'script',
                    'computed_affects'  => [ '__posts', ],
                ),
                'videos_in_feed' => array(
                    'label'           => esc_html__( 'Video / Audio in Feed', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'configuration',
                    'options'         => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'If there are videos- or audio-posts in your defined feed, turn this on to ensure proper functionality. Otherwise, you will get a javascript error.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'script',
                    'computed_affects'  => [ '__posts', ],
                ),
                'scroll_animate_offset' => array(
                    'label'             => esc_html__( 'Scroll Animation Offset', DFBM()->domain() ),
                    'type'              => 'yes_no_button',
                    'option_category'   => 'configuration',
                    'options'           => array(
                        'off' => esc_html__( 'No', DFBM()->domain() ),
                        'on'  => esc_html__( 'Yes', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Enable scroll animation offset. The default value corresponds to your header height. But it can be usefull to redefine it for shrinked headers.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'scroll',
                    'affects' => array(
                        'scroll_offset_height',
                        'scroll_offset_height_mob',
                    ),
                    'computed_affects'  => [ '__posts', ],
                ),
                'scroll_offset_height' => array(
                    'label'           => esc_html__( 'Animation Offset Height', DFBM()->domain() ),
                    'type'            => 'range',
                    'option_category' => 'layout',
                    'default'         => '80',
                    'range_settings'  => array(
                        'min'  => '0',
                        'max'  => '250',
                        'step' => '1',
                    ),
                    'description' => esc_html__( 'Here you can define the scroll animation offset height.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'scroll',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => 'on',
                ),
                'scroll_offset_height_mob' => array(
                    'label'           => esc_html__( 'Animation Offset Height Mobile', DFBM()->domain() ),
                    'type'            => 'range',
                    'option_category' => 'layout',
                    'default'         => '0',
                    'range_settings'  => array(
                        'min'  => '0',
                        'max'  => '250',
                        'step' => '1',
                    ),
                    'description' => esc_html__( 'Here you can define the scroll animation offset height for mobile Devices.', DFBM()->domain() ),
                    'tab_slug'    => 'general',
                    'toggle_slug' => 'scroll',
                    'computed_affects'  => [ '__posts', ],
                    'depends_show_if'  => 'on',
                ),
                'use_inner_shadow' => array(
                    'label'           => esc_html__( 'Use Standard Inner Shadow', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'layout',
                    'options' => array(
                        'on'  => esc_html__( 'On', DFBM()->domain() ),
                        'off' => esc_html__( 'Off', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Here you can add a smooth inner 1px box shadow without blur. But you can also define it in the custom-css settings according to your needs.', DFBM()->domain() ),
                    'tab_slug'    => 'advanced',
                    'toggle_slug' => 'shadow',
                    'computed_affects'  => [ '__posts', ],
                ),
                'use_dropshadow' => array(
                    'label'           => esc_html__( 'Use Dropshadow', DFBM()->domain() ),
                    'type'            => 'yes_no_button',
                    'option_category' => 'layout',
                    'options' => array(
                        'off' => esc_html__( 'Off', DFBM()->domain() ),
                        'on'  => esc_html__( 'On', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Here you can add a smooth drop shadow to your posts.', DFBM()->domain() ),
                    'tab_slug'    => 'advanced',
                    'toggle_slug' => 'shadow',
                    'computed_affects'  => [ '__posts', ],
                ),
                'bg_layout' => array(
                    'label' => esc_html__( 'Text Color', DFBM()->domain() ),
                    'type'  => 'select',
                    'option_category' => 'color_option',
                    'options' => array(
                        'light' => esc_html__( 'Dark', DFBM()->domain() ),
                        'dark'  => esc_html__( 'Light', DFBM()->domain() ),
                    ),
                    'description' => esc_html__( 'Here you can choose whether your text should be light or dark. If you are working with a dark background, then your text should be light. If your background is light, then your text should be set to dark.', DFBM()->domain() ),
                    'tab_slug'    => 'advanced',
                    'toggle_slug' => 'text',
                    'computed_affects'  => [ '__posts', ],
                ),
                'disabled_on' => array(
                    'label'           => esc_html__( 'Disable on', DFBM()->domain() ),
                    'type'            => 'multiple_checkboxes',
                    'options'         => array(
                        'phone'   => esc_html__( 'Phone', DFBM()->domain() ),
                        'tablet'  => esc_html__( 'Tablet', DFBM()->domain() ),
                        'desktop' => esc_html__( 'Desktop', DFBM()->domain() ),
                    ),
                    'additional_att'  => 'disable_on',
                    'option_category' => 'configuration',
                    'description'     => esc_html__( 'This will disable the module on selected devices', DFBM()->domain() ),
                    'tab_slug'        => 'custom_css',
                    'toggle_slug'     => 'visibility',
                ),
                'admin_label' => array(
                    'label'       => esc_html__( 'Admin Label', DFBM()->domain() ),
                    'type'        => 'text',
                    'description' => esc_html__( 'This will change the label of the module in the builder for easy identification.', DFBM()->domain() ),
                    'toggle_slug' => 'admin_label',
                ),
                'module_id' => array(
                    'label'           => esc_html__( 'CSS ID', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'tab_slug'        => 'custom_css',
                    'toggle_slug'     => 'classes',
                    'option_class'    => 'et_pb_custom_css_regular',
                ),
                'module_class' => array(
                    'label'           => esc_html__( 'CSS Class', DFBM()->domain() ),
                    'type'            => 'text',
                    'option_category' => 'configuration',
                    'tab_slug'        => 'custom_css',
                    'toggle_slug'     => 'classes',
                    'option_class'    => 'et_pb_custom_css_regular',
                ),
                '__posts' => array(
                    'type' => 'computed',
                    'computed_callback' => [ 'dfbmModulesFullBlog', 'getBlogPosts' ],
                    'computed_depends_on' => dfbmControllerBlogposts::dependency(),
                ),
            ];

            return array_merge( $first, $second, $third );

        } // end get_fields

        /**
         * Frontend
         *
         * @since 1.0.0
         */
        public static function getBlogPosts( $args = [], $conditional_tags = [], $current_page = [] )
        {

            // return dfbmControllerBlogposts::render( $args, [], false, get_class() );

        } // end getBlogPosts

        /**
         * Render Module Output
         *
         * @since 1.0.0
         */
        function render( $atts, $content = null, $function_name )
        {

            return dfbmControllerBlogposts::render( $this->props, $this->advanced_fields, $this, get_class(), $function_name );

        } // end render
    } // end class
} // end if
